==> aws-java-sdk-1.2.12-sources.jar: com/amazonaws/services/ec2/model/DescribeImageAttributeResult.java <==
/*
 * Copyright 2010-2011 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.ec2.model;

/**
 * <p>
 * The result of describing an AMI attribute.
 * </p>
 */
public class DescribeImageAttributeResult {

    /**
     * The described image attribute of the associated AMI.
     */
    private ImageAttribute imageAttribute;

    /**
     * The described image attribute of the associated AMI.
     *
     * @return The described image attribute of the associated AMI.
     */
    public ImageAttribute getImageAttribute() {
        return imageAttribute;
    }
    
    /**
     * The described image attribute of the associated AMI.
     *
     * @param imageAttribute The described image attribute of the associated AMI.
     */
    public void setImageAttribute(ImageAttribute imageAttribute) {
        this.imageAttribute = imageAttribute;
    }
    
    /**
     * The described image attribute of the associated AMI.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param imageAttribute The described image attribute of the associated AMI.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public DescribeImageAttributeResult withImageAttribute(ImageAttribute imageAttribute) {
        this.imageAttribute = imageAttribute;
        return this;
    }
    
    
    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        sb.append("ImageAttribute: " + imageAttribute + ", ");
        sb.append("}");
        return sb.toString();
    }
    
}

==> aws-java-sdk-1.3.26-sources.jar: com/amazonaws/services/ec2/model/DescribeImageAttributeResult.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.ec2.model;

/**
 * <p>
 * The result of describing an AMI attribute.
 * </p>
 */
public class DescribeImageAttributeResult {

    /**
     * The described image attribute of the associated AMI.
     */
    private ImageAttribute imageAttribute;

    /**
     * The described image attribute of the associated AMI.
     *
     * @return The described image attribute of the associated AMI.
     */
    public ImageAttribute getImageAttribute() {
        return imageAttribute;
    }
    
    /**
     * The described image attribute of the associated AMI.
     *
     * @param imageAttribute The described image attribute of the associated AMI.
     */
    public void setImageAttribute(ImageAttribute imageAttribute) {
        this.imageAttribute = imageAttribute;
    }
    
    /**
     * The described image attribute of the associated AMI.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param imageAttribute The described image attribute of the associated AMI.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public DescribeImageAttributeResult withImageAttribute(ImageAttribute imageAttribute) {
        this.imageAttribute = imageAttribute;
        return this;
    }
    
    
    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (imageAttribute != null) sb.append("ImageAttribute: " + imageAttribute + ", ");
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getImageAttribute() == null) ? 0 : getImageAttribute().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;
    
        if (obj instanceof DescribeImageAttributeResult == false) return false;
        DescribeImageAttributeResult other = (DescribeImageAttributeResult)obj;
        
        if (other.getImageAttribute() == null ^ this.getImageAttribute() == null) return false;
        if (other.getImageAttribute() != null && other.getImageAttribute().equals(this.getImageAttribute()) == false) return false; 
        return true;
    }
    
}
